@@ -17,7 +17,7 @@ class MetaPubObject(object):
         if root:
             return dom.find(root)
         else:
-            return dom.getchildren()[0]    
+            return dom
 
     def _get(self, tag):
         n = self.content.find(tag)
@@ -25,3 +25,10 @@ class MetaPubObject(object):
             return n.text
         return None
 
+# singleton class used by the fetchers.
+class Borg(object):
+    _shared_state = {}
+    def __init__(self):
+        self.__dict__ = self._shared_state
+
+
